setwd("/home/sesa/Scrivania/")

#Load Data
data_size<-read.table("stats_size.csv",sep=",",header=TRUE)
data<-read.table("stats_experience.csv",sep=",",header=TRUE)
#id,bug,lines,hunks
#id,bug,ccdb,ccdbm,ccdbmm,kdb,cct,cctm,cctmm,kt

#id : commit ID
#bug : true if commit is a fix inducing change
#ccdb : Conceptual Coupling Dynamic Background (text currentCommit - text background)
#ccdbm : Conceptual Coupling Dynamic Background (mean foreach file: text file - text background)
#ccdbmm : Conceptual Coupling Dynamic Background (median foreach file: text file - text background)
#kdb : Knowledge Dynamic Background
#cct : Conceptual Coupling Progressive Loss of Memory Time Treshold (text currentCommit - text background)
#cctm : Conceptual Coupling Progressive Loss of Memory Time Treshold (mean foreach file: text file - text background)
#cctmm : Conceptual Coupling Progressive Loss of Memory Time Treshold (median foreach file: text file - text background)
#kt : Knowledge Progressive Loss of Memory Time Treshold

#This is the mapping for the variables used in the paper:
#ExpLex -> CCDBM
#ExpRecLex -> CCTM
#ExpFreq -> KDB
#ExpRecFreq -> KT 


data <- data[which(data["ccdb"] != "NaN"),]
data <- data[which(data["ccdbm"] != "NaN"),]
data <- data[which(data["ccdbmm"] != "NaN"),]
data <- data[which(data["kdb"] != "NaN"),]
data <- data[which(data["cct"] != "NaN"),]
data <- data[which(data["cctm"] != "NaN"),]
data <- data[which(data["cctmm"] != "NaN"),]
data <- data[which(data["kt"] != "NaN"),]

table <- merge(x=data_size, y=data, by="id", all.y=TRUE)

#Subset of the table's columns for which we compute the correlation
a<-c("lines","hunks","ccdb","ccdbm","ccdbmm","kdb","cct","cctm","cctmm","kt")

#COMPUTE FIRST TABLE
#init list
res<-list(M1=c(),M2=c(),RHO=c(),PVALUE=c())

#cycles without repetitions
for(i in 1:(length(a))){
  for(j in (1):length(a)){
    #'table[[a[i]]]' selects the column of 'table' with 'header=a[i]'
    m<-cor.test(table[[a[i]]],table[[a[j]]],method="spearman")
    res$M1<-c(res$M1,a[i])
    res$M2<-c(res$M2,a[j])
    res$RHO<-c(res$RHO,m$estimate)
    res$PVALUE<-c(res$PVALUE,m$p.value)
    }
}


#Latex output
res=data.frame(res)
write.table(res,"/home/sesa/Scrivania/correlation1.csv",sep = ",",row.names=FALSE)

#COMPUTE SECOND TABLE
#init matrix
res2<-matrix(-1,length(a),length(a))
colnames(res2)<-a
rownames(res2)<-a

#cycles without repetitions
for(i in 1:(length(a))){
  for(j in (1):length(a)){
     m<-cor.test(table[[a[i]]],table[[a[j]]],method="spearman")
     res2[i,j]<-m$estimate
    }
}

#Latex output
res2=as.data.frame(res2)
write.table(res2,"/home/sesa/Scrivania/correlation2.csv",sep = ",")


#Generate developers' experience boxplots
summary(table$kdb)

q1 <- quantile(table$kdb, 0.25,type=7)
q3 <- quantile(table$kdb, 0.75,type=7)

low <- table[which(table["kdb"] < q1),]
medium <- table[which(table["kdb"] < q3 & table["kdb"] > q1),]
high <- table[which(table["kdb"] > q3),]

#Shows the number of observations in each category (defined by the quartiles)
print("Developers low experience: ")
print(nrow(low));
print("Developers medium experience: ")
print(nrow(medium));
print("Developers high experience: ")
print(nrow(high));


pdf("boxplot_corelation.pdf")
boxplot(low$hunks, medium$hunks, high$hunks, col="gray", boxwex = 0.25, at = 1:3 - 0.0, names = c("low","medium", "high"), xlab="Developers Experience (ExpFreq)", ylab="Hunks", ylim=c(0,150))
dev.off()

